@@ -20,18 +20,20 @@ from redis.commands.graph.query_result import (
     QueryResult,
 )
 from redis.exceptions import ResponseError
-from tests.conftest import _get_client, skip_if_redis_enterprise
+from tests.conftest import _get_client, skip_if_redis_enterprise, skip_if_resp_version
 
 
 @pytest.fixture
-def client(request):
-    r = _get_client(Redis, request, decode_responses=True)
+def client(request, stack_url):
+    r = _get_client(
+        Redis, request, decode_responses=True, from_url="redis://localhost:6480"
+    )
     r.flushdb()
     return r
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_bulk(client):
     with pytest.raises(NotImplementedError):
         client.graph().bulk()
@@ -39,7 +41,7 @@ def test_bulk(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_graph_creation(client):
     graph = client.graph()
 
@@ -85,7 +87,7 @@ def test_graph_creation(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_array_functions(client):
     query = """CREATE (p:person{name:'a',age:32, array:[0,1,2]})"""
     client.graph().query(query)
@@ -107,7 +109,7 @@ def test_array_functions(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_path(client):
     node0 = Node(node_id=0, label="L1")
     node1 = Node(node_id=1, label="L1")
@@ -128,7 +130,7 @@ def test_path(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_param(client):
     params = [1, 2.3, "str", True, False, None, [0, 1, 2], r"\" RETURN 1337 //"]
     query = "RETURN $param"
@@ -139,7 +141,7 @@ def test_param(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_map(client):
     query = "RETURN {a:1, b:'str', c:NULL, d:[1,2,3], e:True, f:{x:1, y:2}}"
 
@@ -157,7 +159,7 @@ def test_map(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_point(client):
     query = "RETURN point({latitude: 32.070794860, longitude: 34.820751118})"
     expected_lat = 32.070794860
@@ -175,7 +177,7 @@ def test_point(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_index_response(client):
     result_set = client.graph().query("CREATE INDEX ON :person(age)")
     assert 1 == result_set.indices_created
@@ -191,7 +193,7 @@ def test_index_response(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_stringify_query_result(client):
     graph = client.graph()
 
@@ -246,7 +248,7 @@ def test_stringify_query_result(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_optional_match(client):
     # Build a graph of form (a)-[R]->(b)
     node0 = Node(node_id=0, label="L1", properties={"value": "a"})
@@ -272,7 +274,7 @@ def test_optional_match(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_cached_execution(client):
     client.graph().query("CREATE ()")
 
@@ -291,7 +293,7 @@ def test_cached_execution(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_slowlog(client):
     create_query = """CREATE (:Rider
     {name:'Valentino Rossi'})-[:rides]->(:Team {name:'Yamaha'}),
@@ -305,8 +307,8 @@ def test_slowlog(client):
 
 
 @pytest.mark.redismod
+@skip_if_resp_version(3)
 @pytest.mark.xfail(strict=False)
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_query_timeout(client):
     # Build a sample graph with 1000 nodes.
     client.graph().query("UNWIND range(0,1000) as val CREATE ({v: val})")
@@ -321,7 +323,7 @@ def test_query_timeout(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_read_only_query(client):
     with pytest.raises(Exception):
         # Issue a write query, specifying read-only true,
@@ -331,7 +333,7 @@ def test_read_only_query(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_profile(client):
     q = """UNWIND range(1, 3) AS x CREATE (p:Person {v:x})"""
     profile = client.graph().profile(q).result_set
@@ -347,8 +349,8 @@ def test_profile(client):
 
 
 @pytest.mark.redismod
+@skip_if_resp_version(3)
 @skip_if_redis_enterprise()
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_config(client):
     config_name = "RESULTSET_SIZE"
     config_value = 3
@@ -381,7 +383,7 @@ def test_config(client):
 
 @pytest.mark.onlynoncluster
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_list_keys(client):
     result = client.graph().list_keys()
     assert result == []
@@ -405,7 +407,7 @@ def test_list_keys(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_multi_label(client):
     redis_graph = client.graph("g")
 
@@ -432,7 +434,7 @@ def test_multi_label(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_cache_sync(client):
     pass
     return
@@ -506,7 +508,7 @@ def test_cache_sync(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_execution_plan(client):
     redis_graph = client.graph("execution_plan")
     create_query = """CREATE
@@ -526,7 +528,7 @@ def test_execution_plan(client):
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_explain(client):
     redis_graph = client.graph("execution_plan")
     # graph creation / population
@@ -616,7 +618,7 @@ Project
 
 
 @pytest.mark.redismod
-@pytest.mark.skip(reason="Graph module removed from Redis Stack")
+@skip_if_resp_version(3)
 def test_resultset_statistics(client):
     with patch.object(target=QueryResult, attribute="_get_stat") as mock_get_stats:
         result = client.graph().query("RETURN 1")
