@@ -8,12 +8,13 @@ from .conftest import _get_client, assert_resp_response, skip_ifmodversion_lt
 
 
 @pytest.fixture
-def client(request):
-    r = _get_client(Redis, request, decode_responses=True)
+def client(request, stack_url):
+    r = _get_client(Redis, request, decode_responses=True, from_url=stack_url)
     r.flushdb()
     return r
 
 
+@pytest.mark.redismod
 def test_json_setbinarykey(client):
     d = {"hello": "world", b"some": "value"}
     with pytest.raises(TypeError):
@@ -21,28 +22,32 @@ def test_json_setbinarykey(client):
     assert client.json().set("somekey", Path.root_path(), d, decode_keys=True)
 
 
+@pytest.mark.redismod
 def test_json_setgetdeleteforget(client):
     assert client.json().set("foo", Path.root_path(), "bar")
-    assert_resp_response(client, client.json().get("foo"), "bar", [["bar"]])
+    assert client.json().get("foo") == "bar"
     assert client.json().get("baz") is None
     assert client.json().delete("foo") == 1
     assert client.json().forget("foo") == 0  # second delete
     assert client.exists("foo") == 0
 
 
+@pytest.mark.redismod
 def test_jsonget(client):
     client.json().set("foo", Path.root_path(), "bar")
-    assert_resp_response(client, client.json().get("foo"), "bar", [["bar"]])
+    assert client.json().get("foo") == "bar"
 
 
+@pytest.mark.redismod
 def test_json_get_jset(client):
     assert client.json().set("foo", Path.root_path(), "bar")
-    assert_resp_response(client, client.json().get("foo"), "bar", [["bar"]])
+    assert client.json().get("foo") == "bar"
     assert client.json().get("baz") is None
     assert 1 == client.json().delete("foo")
     assert client.exists("foo") == 0
 
 
+@pytest.mark.redismod
 @skip_ifmodversion_lt("2.06.00", "ReJSON")  # todo: update after the release
 def test_json_merge(client):
     # Test with root path $
@@ -75,16 +80,15 @@ def test_json_merge(client):
     }
 
 
+@pytest.mark.redismod
 def test_nonascii_setgetdelete(client):
     assert client.json().set("notascii", Path.root_path(), "hyvää-élève")
-    res = "hyvää-élève"
-    assert_resp_response(
-        client, client.json().get("notascii", no_escape=True), res, [[res]]
-    )
+    assert client.json().get("notascii", no_escape=True) == "hyvää-élève"
     assert 1 == client.json().delete("notascii")
     assert client.exists("notascii") == 0
 
 
+@pytest.mark.redismod
 def test_jsonsetexistentialmodifiersshouldsucceed(client):
     obj = {"foo": "bar"}
     assert client.json().set("obj", Path.root_path(), obj)
@@ -97,12 +101,12 @@ def test_jsonsetexistentialmodifiersshouldsucceed(client):
     assert client.json().set("obj", Path("foo"), "baz", xx=True)
     assert client.json().set("obj", Path("qaz"), "baz", nx=True)
 
-    # Test that flags are mutually exlusive
+    # Test that flags are mutually exclusive
     with pytest.raises(Exception):
         client.json().set("obj", Path("foo"), "baz", nx=True, xx=True)
 
 
-@pytest.mark.onlynoncluster
+@pytest.mark.redismod
 def test_mgetshouldsucceed(client):
     client.json().set("1", Path.root_path(), 1)
     client.json().set("2", Path.root_path(), 2)
@@ -112,6 +116,7 @@ def test_mgetshouldsucceed(client):
 
 
 @pytest.mark.onlynoncluster
+@pytest.mark.redismod
 @skip_ifmodversion_lt("2.06.00", "ReJSON")
 def test_mset(client):
     client.json().mset([("1", Path.root_path(), 1), ("2", Path.root_path(), 2)])
@@ -120,13 +125,15 @@ def test_mset(client):
     assert client.json().mget(["1", "2"], Path.root_path()) == [1, 2]
 
 
+@pytest.mark.redismod
 @skip_ifmodversion_lt("99.99.99", "ReJSON")  # todo: update after the release
 def test_clear(client):
     client.json().set("arr", Path.root_path(), [0, 1, 2, 3, 4])
     assert 1 == client.json().clear("arr", Path.root_path())
-    assert_resp_response(client, client.json().get("arr"), [], [[[]]])
+    assert_resp_response(client, client.json().get("arr"), [], [])
 
 
+@pytest.mark.redismod
 def test_type(client):
     client.json().set("1", Path.root_path(), 1)
     assert_resp_response(
@@ -135,6 +142,7 @@ def test_type(client):
     assert_resp_response(client, client.json().type("1"), "integer", ["integer"])
 
 
+@pytest.mark.redismod
 def test_numincrby(client):
     client.json().set("num", Path.root_path(), 1)
     assert_resp_response(
@@ -148,6 +156,7 @@ def test_numincrby(client):
     )
 
 
+@pytest.mark.redismod
 def test_nummultby(client):
     client.json().set("num", Path.root_path(), 1)
 
@@ -163,6 +172,7 @@ def test_nummultby(client):
         )
 
 
+@pytest.mark.redismod
 @skip_ifmodversion_lt("99.99.99", "ReJSON")  # todo: update after the release
 def test_toggle(client):
     client.json().set("bool", Path.root_path(), False)
@@ -174,23 +184,14 @@ def test_toggle(client):
         client.json().toggle("num", Path.root_path())
 
 
+@pytest.mark.redismod
 def test_strappend(client):
     client.json().set("jsonkey", Path.root_path(), "foo")
     assert 6 == client.json().strappend("jsonkey", "bar")
-    assert_resp_response(
-        client, client.json().get("jsonkey", Path.root_path()), "foobar", [["foobar"]]
-    )
-
-
-# # def test_debug(client):
-#    client.json().set("str", Path.root_path(), "foo")
-#    assert 24 == client.json().debug("MEMORY", "str", Path.root_path())
-#    assert 24 == client.json().debug("MEMORY", "str")
-#
-#    # technically help is valid
-#    assert isinstance(client.json().debug("HELP"), list)
+    assert "foobar" == client.json().get("jsonkey", Path.root_path())
 
 
+@pytest.mark.redismod
 def test_strlen(client):
     client.json().set("str", Path.root_path(), "foo")
     assert 3 == client.json().strlen("str", Path.root_path())
@@ -199,6 +200,7 @@ def test_strlen(client):
     assert 6 == client.json().strlen("str")
 
 
+@pytest.mark.redismod
 def test_arrappend(client):
     client.json().set("arr", Path.root_path(), [1])
     assert 2 == client.json().arrappend("arr", Path.root_path(), 2)
@@ -206,6 +208,7 @@ def test_arrappend(client):
     assert 7 == client.json().arrappend("arr", Path.root_path(), *[5, 6, 7])
 
 
+@pytest.mark.redismod
 def test_arrindex(client):
     client.json().set("arr", Path.root_path(), [0, 1, 2, 3, 4])
     assert 1 == client.json().arrindex("arr", Path.root_path(), 1)
@@ -217,19 +220,19 @@ def test_arrindex(client):
     assert -1 == client.json().arrindex("arr", Path.root_path(), 4, start=1, stop=3)
 
 
+@pytest.mark.redismod
 def test_arrinsert(client):
     client.json().set("arr", Path.root_path(), [0, 4])
     assert 5 - -client.json().arrinsert("arr", Path.root_path(), 1, *[1, 2, 3])
-    res = [0, 1, 2, 3, 4]
-    assert_resp_response(client, client.json().get("arr"), res, [[res]])
+    assert client.json().get("arr") == [0, 1, 2, 3, 4]
 
     # test prepends
     client.json().set("val2", Path.root_path(), [5, 6, 7, 8, 9])
     client.json().arrinsert("val2", Path.root_path(), 0, ["some", "thing"])
-    res = [["some", "thing"], 5, 6, 7, 8, 9]
-    assert_resp_response(client, client.json().get("val2"), res, [[res]])
+    assert client.json().get("val2") == [["some", "thing"], 5, 6, 7, 8, 9]
 
 
+@pytest.mark.redismod
 def test_arrlen(client):
     client.json().set("arr", Path.root_path(), [0, 1, 2, 3, 4])
     assert 5 == client.json().arrlen("arr", Path.root_path())
@@ -237,13 +240,14 @@ def test_arrlen(client):
     assert client.json().arrlen("fakekey") is None
 
 
+@pytest.mark.redismod
 def test_arrpop(client):
     client.json().set("arr", Path.root_path(), [0, 1, 2, 3, 4])
     assert 4 == client.json().arrpop("arr", Path.root_path(), 4)
     assert 3 == client.json().arrpop("arr", Path.root_path(), -1)
     assert 2 == client.json().arrpop("arr", Path.root_path())
     assert 0 == client.json().arrpop("arr", Path.root_path(), 0)
-    assert_resp_response(client, client.json().get("arr"), [1], [[[1]]])
+    assert [1] == client.json().get("arr")
 
     # test out of bounds
     client.json().set("arr", Path.root_path(), [0, 1, 2, 3, 4])
@@ -254,10 +258,11 @@ def test_arrpop(client):
     assert client.json().arrpop("arr") is None
 
 
+@pytest.mark.redismod
 def test_arrtrim(client):
     client.json().set("arr", Path.root_path(), [0, 1, 2, 3, 4])
     assert 3 == client.json().arrtrim("arr", Path.root_path(), 1, 3)
-    assert_resp_response(client, client.json().get("arr"), [1, 2, 3], [[[1, 2, 3]]])
+    assert [1, 2, 3] == client.json().get("arr")
 
     # <0 test, should be 0 equivalent
     client.json().set("arr", Path.root_path(), [0, 1, 2, 3, 4])
@@ -276,6 +281,7 @@ def test_arrtrim(client):
     assert 0 == client.json().arrtrim("arr", Path.root_path(), 9, 11)
 
 
+@pytest.mark.redismod
 def test_resp(client):
     obj = {"foo": "bar", "baz": 1, "qaz": True}
     client.json().set("obj", Path.root_path(), obj)
@@ -285,6 +291,7 @@ def test_resp(client):
     assert isinstance(client.json().resp("obj"), list)
 
 
+@pytest.mark.redismod
 def test_objkeys(client):
     obj = {"foo": "bar", "baz": "qaz"}
     client.json().set("obj", Path.root_path(), obj)
@@ -301,6 +308,7 @@ def test_objkeys(client):
     assert client.json().objkeys("fakekey") is None
 
 
+@pytest.mark.redismod
 def test_objlen(client):
     obj = {"foo": "bar", "baz": "qaz"}
     client.json().set("obj", Path.root_path(), obj)
@@ -310,12 +318,13 @@ def test_objlen(client):
     assert len(obj) == client.json().objlen("obj")
 
 
+@pytest.mark.redismod
 def test_json_commands_in_pipeline(client):
     p = client.json().pipeline()
     p.set("foo", Path.root_path(), "bar")
     p.get("foo")
     p.delete("foo")
-    assert_resp_response(client, p.execute(), [True, "bar", 1], [True, [["bar"]], 1])
+    assert p.execute() == [True, "bar", 1]
     assert client.keys() == []
     assert client.get("foo") is None
 
@@ -328,23 +337,24 @@ def test_json_commands_in_pipeline(client):
         p.jsonget("foo")
     p.exists("notarealkey")
     p.delete("foo")
-    assert_resp_response(client, p.execute(), [True, d, 0, 1], [True, [[d]], 0, 1])
+    assert p.execute() == [True, d, 0, 1]
     assert client.keys() == []
     assert client.get("foo") is None
 
 
+@pytest.mark.redismod
 def test_json_delete_with_dollar(client):
     doc1 = {"a": 1, "nested": {"a": 2, "b": 3}}
     assert client.json().set("doc1", "$", doc1)
     assert client.json().delete("doc1", "$..a") == 2
     res = [{"nested": {"b": 3}}]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     doc2 = {"a": {"a": 2, "b": 3}, "b": ["a", "b"], "nested": {"b": [True, "a", "b"]}}
     assert client.json().set("doc2", "$", doc2)
     assert client.json().delete("doc2", "$..a") == 1
     res = [{"nested": {"b": [True, "a", "b"]}, "b": ["a", "b"]}]
-    assert_resp_response(client, client.json().get("doc2", "$"), res, [res])
+    assert client.json().get("doc2", "$") == res
 
     doc3 = [
         {
@@ -375,7 +385,7 @@ def test_json_delete_with_dollar(client):
             }
         ]
     ]
-    assert_resp_response(client, client.json().get("doc3", "$"), doc3val, [doc3val])
+    assert client.json().get("doc3", "$") == doc3val
 
     # Test default path
     assert client.json().delete("doc3") == 1
@@ -384,18 +394,19 @@ def test_json_delete_with_dollar(client):
     client.json().delete("not_a_document", "..a")
 
 
+@pytest.mark.redismod
 def test_json_forget_with_dollar(client):
     doc1 = {"a": 1, "nested": {"a": 2, "b": 3}}
     assert client.json().set("doc1", "$", doc1)
     assert client.json().forget("doc1", "$..a") == 2
     res = [{"nested": {"b": 3}}]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     doc2 = {"a": {"a": 2, "b": 3}, "b": ["a", "b"], "nested": {"b": [True, "a", "b"]}}
     assert client.json().set("doc2", "$", doc2)
     assert client.json().forget("doc2", "$..a") == 1
     res = [{"nested": {"b": [True, "a", "b"]}, "b": ["a", "b"]}]
-    assert_resp_response(client, client.json().get("doc2", "$"), res, [res])
+    assert client.json().get("doc2", "$") == res
 
     doc3 = [
         {
@@ -426,7 +437,7 @@ def test_json_forget_with_dollar(client):
             }
         ]
     ]
-    assert_resp_response(client, client.json().get("doc3", "$"), doc3val, [doc3val])
+    assert client.json().get("doc3", "$") == doc3val
 
     # Test default path
     assert client.json().forget("doc3") == 1
@@ -435,6 +446,7 @@ def test_json_forget_with_dollar(client):
     client.json().forget("not_a_document", "..a")
 
 
+@pytest.mark.redismod
 def test_json_mget_dollar(client):
     # Test mget with multi paths
     client.json().set(
@@ -449,21 +461,22 @@ def test_json_mget_dollar(client):
     )
     # Compare also to single JSON.GET
     res = [1, 3, None]
-    assert_resp_response(client, client.json().get("doc1", "$..a"), res, [res])
+    assert client.json().get("doc1", "$..a") == res
     res = [4, 6, [None]]
-    assert_resp_response(client, client.json().get("doc2", "$..a"), res, [res])
+    assert client.json().get("doc2", "$..a") == res
 
     # Test mget with single path
-    client.json().mget("doc1", "$..a") == [1, 3, None]
+    assert client.json().mget(["doc1"], "$..a") == [[1, 3, None]]
     # Test mget with multi path
-    client.json().mget(["doc1", "doc2"], "$..a") == [[1, 3, None], [4, 6, [None]]]
+    res = [[1, 3, None], [4, 6, [None]]]
+    assert client.json().mget(["doc1", "doc2"], "$..a") == res
 
     # Test missing key
-    client.json().mget(["doc1", "missing_doc"], "$..a") == [[1, 3, None], None]
-    res = client.json().mget(["missing_doc1", "missing_doc2"], "$..a")
-    assert res == [None, None]
+    assert client.json().mget(["doc1", "missing_doc"], "$..a") == [[1, 3, None], None]
+    assert client.json().mget(["missing_doc1", "missing_doc2"], "$..a") == [None, None]
 
 
+@pytest.mark.redismod
 def test_numby_commands_dollar(client):
     # Test NUMINCRBY
     client.json().set("doc1", "$", {"a": "b", "b": [{"a": 2}, {"a": 5.0}, {"a": "c"}]})
@@ -498,45 +511,49 @@ def test_numby_commands_dollar(client):
 
     # Test legacy NUMINCRBY
     client.json().set("doc1", "$", {"a": "b", "b": [{"a": 2}, {"a": 5.0}, {"a": "c"}]})
-    client.json().numincrby("doc1", ".b[0].a", 3) == 5
+    assert_resp_response(client, client.json().numincrby("doc1", ".b[0].a", 3), 5, [5])
 
     # Test legacy NUMMULTBY
     client.json().set("doc1", "$", {"a": "b", "b": [{"a": 2}, {"a": 5.0}, {"a": "c"}]})
 
     with pytest.deprecated_call():
-        client.json().nummultby("doc1", ".b[0].a", 3) == 6
+        assert_resp_response(
+            client, client.json().nummultby("doc1", ".b[0].a", 3), 6, [6]
+        )
 
 
+@pytest.mark.redismod
 def test_strappend_dollar(client):
     client.json().set(
         "doc1", "$", {"a": "foo", "nested1": {"a": "hello"}, "nested2": {"a": 31}}
     )
     # Test multi
-    client.json().strappend("doc1", "bar", "$..a") == [6, 8, None]
+    assert client.json().strappend("doc1", "bar", "$..a") == [6, 8, None]
 
-    # res = [{"a": "foobar", "nested1": {"a": "hellobar"}, "nested2": {"a": 31}}]
-    # assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    res = [{"a": "foobar", "nested1": {"a": "hellobar"}, "nested2": {"a": 31}}]
+    assert_resp_response(client, client.json().get("doc1", "$"), res, res)
 
     # Test single
-    client.json().strappend("doc1", "baz", "$.nested1.a") == [11]
+    assert client.json().strappend("doc1", "baz", "$.nested1.a") == [11]
 
-    # res = [{"a": "foobar", "nested1": {"a": "hellobarbaz"}, "nested2": {"a": 31}}]
-    # assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    res = [{"a": "foobar", "nested1": {"a": "hellobarbaz"}, "nested2": {"a": 31}}]
+    assert_resp_response(client, client.json().get("doc1", "$"), res, res)
 
     # Test missing key
     with pytest.raises(exceptions.ResponseError):
         client.json().strappend("non_existing_doc", "$..a", "err")
 
     # Test multi
-    client.json().strappend("doc1", "bar", ".*.a") == 8
-    # res = [{"a": "foo", "nested1": {"a": "hellobar"}, "nested2": {"a": 31}}]
-    # assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().strappend("doc1", "bar", ".*.a") == 14
+    res = [{"a": "foobar", "nested1": {"a": "hellobarbazbar"}, "nested2": {"a": 31}}]
+    assert_resp_response(client, client.json().get("doc1", "$"), res, res)
 
     # Test missing path
     with pytest.raises(exceptions.ResponseError):
         client.json().strappend("doc1", "piu")
 
 
+@pytest.mark.redismod
 def test_strlen_dollar(client):
     # Test multi
     client.json().set(
@@ -549,14 +566,15 @@ def test_strlen_dollar(client):
     assert res1 == res2
 
     # Test single
-    client.json().strlen("doc1", "$.nested1.a") == [8]
-    client.json().strlen("doc1", "$.nested2.a") == [None]
+    assert client.json().strlen("doc1", "$.nested1.a") == [8]
+    assert client.json().strlen("doc1", "$.nested2.a") == [None]
 
     # Test missing key
     with pytest.raises(exceptions.ResponseError):
         client.json().strlen("non_existing_doc", "$..a")
 
 
+@pytest.mark.redismod
 def test_arrappend_dollar(client):
     client.json().set(
         "doc1",
@@ -568,7 +586,7 @@ def test_arrappend_dollar(client):
         },
     )
     # Test multi
-    client.json().arrappend("doc1", "$..a", "bar", "racuda") == [3, 5, None]
+    assert client.json().arrappend("doc1", "$..a", "bar", "racuda") == [3, 5, None]
     res = [
         {
             "a": ["foo", "bar", "racuda"],
@@ -576,7 +594,7 @@ def test_arrappend_dollar(client):
             "nested2": {"a": 31},
         }
     ]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     # Test single
     assert client.json().arrappend("doc1", "$.nested1.a", "baz") == [6]
@@ -587,7 +605,7 @@ def test_arrappend_dollar(client):
             "nested2": {"a": 31},
         }
     ]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     # Test missing key
     with pytest.raises(exceptions.ResponseError):
@@ -613,7 +631,7 @@ def test_arrappend_dollar(client):
             "nested2": {"a": 31},
         }
     ]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     # Test single
     assert client.json().arrappend("doc1", ".nested1.a", "baz") == 6
@@ -624,13 +642,14 @@ def test_arrappend_dollar(client):
             "nested2": {"a": 31},
         }
     ]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     # Test missing key
     with pytest.raises(exceptions.ResponseError):
         client.json().arrappend("non_existing_doc", "$..a")
 
 
+@pytest.mark.redismod
 def test_arrinsert_dollar(client):
     client.json().set(
         "doc1",
@@ -651,7 +670,7 @@ def test_arrinsert_dollar(client):
             "nested2": {"a": 31},
         }
     ]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     # Test single
     assert client.json().arrinsert("doc1", "$.nested1.a", -2, "baz") == [6]
@@ -662,13 +681,14 @@ def test_arrinsert_dollar(client):
             "nested2": {"a": 31},
         }
     ]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     # Test missing key
     with pytest.raises(exceptions.ResponseError):
         client.json().arrappend("non_existing_doc", "$..a")
 
 
+@pytest.mark.redismod
 def test_arrlen_dollar(client):
     client.json().set(
         "doc1",
@@ -717,6 +737,7 @@ def test_arrlen_dollar(client):
     assert client.json().arrlen("non_existing_doc", "..a") is None
 
 
+@pytest.mark.redismod
 def test_arrpop_dollar(client):
     client.json().set(
         "doc1",
@@ -732,7 +753,7 @@ def test_arrpop_dollar(client):
     assert client.json().arrpop("doc1", "$..a", 1) == ['"foo"', None, None]
 
     res = [{"a": [], "nested1": {"a": ["hello", "world"]}, "nested2": {"a": 31}}]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     # Test missing key
     with pytest.raises(exceptions.ResponseError):
@@ -749,15 +770,16 @@ def test_arrpop_dollar(client):
         },
     )
     # Test multi (all paths are updated, but return result of last path)
-    client.json().arrpop("doc1", "..a", "1") is None
+    assert client.json().arrpop("doc1", "..a", "1") == "null"
     res = [{"a": [], "nested1": {"a": ["hello", "world"]}, "nested2": {"a": 31}}]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     # # Test missing key
     with pytest.raises(exceptions.ResponseError):
         client.json().arrpop("non_existing_doc", "..a")
 
 
+@pytest.mark.redismod
 def test_arrtrim_dollar(client):
     client.json().set(
         "doc1",
@@ -771,16 +793,16 @@ def test_arrtrim_dollar(client):
     # Test multi
     assert client.json().arrtrim("doc1", "$..a", "1", -1) == [0, 2, None]
     res = [{"a": [], "nested1": {"a": [None, "world"]}, "nested2": {"a": 31}}]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     assert client.json().arrtrim("doc1", "$..a", "1", "1") == [0, 1, None]
     res = [{"a": [], "nested1": {"a": ["world"]}, "nested2": {"a": 31}}]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     # Test single
     assert client.json().arrtrim("doc1", "$.nested1.a", 1, 0) == [0]
     res = [{"a": [], "nested1": {"a": []}, "nested2": {"a": 31}}]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     # Test missing key
     with pytest.raises(exceptions.ResponseError):
@@ -803,13 +825,14 @@ def test_arrtrim_dollar(client):
     # Test single
     assert client.json().arrtrim("doc1", ".nested1.a", "1", "1") == 1
     res = [{"a": [], "nested1": {"a": ["world"]}, "nested2": {"a": 31}}]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     # Test missing key
     with pytest.raises(exceptions.ResponseError):
         client.json().arrtrim("non_existing_doc", "..a", 1, 1)
 
 
+@pytest.mark.redismod
 def test_objkeys_dollar(client):
     client.json().set(
         "doc1",
@@ -839,6 +862,7 @@ def test_objkeys_dollar(client):
     assert client.json().objkeys("doc1", "$..nowhere") == []
 
 
+@pytest.mark.redismod
 def test_objlen_dollar(client):
     client.json().set(
         "doc1",
@@ -893,6 +917,7 @@ def load_types_data(nested_key_name):
     return jdata, types
 
 
+@pytest.mark.redismod
 def test_type_dollar(client):
     jdata, jtypes = load_types_data("a")
     client.json().set("doc1", "$", jdata)
@@ -910,6 +935,7 @@ def test_type_dollar(client):
     )
 
 
+@pytest.mark.redismod
 def test_clear_dollar(client):
     client.json().set(
         "doc1",
@@ -927,7 +953,7 @@ def test_clear_dollar(client):
     res = [
         {"nested1": {"a": {}}, "a": [], "nested2": {"a": "claro"}, "nested3": {"a": {}}}
     ]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     # Test single
     client.json().set(
@@ -949,17 +975,18 @@ def test_clear_dollar(client):
             "nested3": {"a": {"baz": 50}},
         }
     ]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     # Test missing path (defaults to root)
     assert client.json().clear("doc1") == 1
-    assert_resp_response(client, client.json().get("doc1", "$"), [{}], [[{}]])
+    assert client.json().get("doc1", "$") == [{}]
 
     # Test missing key
     with pytest.raises(exceptions.ResponseError):
         client.json().clear("non_existing_doc", "$..a")
 
 
+@pytest.mark.redismod
 def test_toggle_dollar(client):
     client.json().set(
         "doc1",
@@ -981,35 +1008,14 @@ def test_toggle_dollar(client):
             "nested3": {"a": False},
         }
     ]
-    assert_resp_response(client, client.json().get("doc1", "$"), res, [res])
+    assert client.json().get("doc1", "$") == res
 
     # Test missing key
     with pytest.raises(exceptions.ResponseError):
         client.json().toggle("non_existing_doc", "$..a")
 
 
-# # def test_debug_dollar(client):
-#
-#    jdata, jtypes = load_types_data("a")
-#
-#    client.json().set("doc1", "$", jdata)
-#
-#    # Test multi
-#    assert client.json().debug("MEMORY", "doc1", "$..a") == [72, 24, 24, 16, 16, 1, 0]
-#
-#    # Test single
-#    assert client.json().debug("MEMORY", "doc1", "$.nested2.a") == [24]
-#
-#    # Test legacy
-#    assert client.json().debug("MEMORY", "doc1", "..a") == 72
-#
-#    # Test missing path (defaults to root)
-#    assert client.json().debug("MEMORY", "doc1") == 72
-#
-#    # Test missing key
-#    assert client.json().debug("MEMORY", "non_existing_doc", "$..a") == []
-
-
+@pytest.mark.redismod
 def test_resp_dollar(client):
     data = {
         "L1": {
@@ -1238,6 +1244,7 @@ def test_resp_dollar(client):
     client.json().resp("non_existing_doc", "$..a")
 
 
+@pytest.mark.redismod
 def test_arrindex_dollar(client):
     client.json().set(
         "store",
@@ -1281,12 +1288,10 @@ def test_arrindex_dollar(client):
         },
     )
 
-    assert_resp_response(
-        client,
-        client.json().get("store", "$.store.book[?(@.price<10)].size"),
-        [[10, 20, 30, 40], [5, 10, 20, 30]],
-        [[[10, 20, 30, 40], [5, 10, 20, 30]]],
-    )
+    assert client.json().get("store", "$.store.book[?(@.price<10)].size") == [
+        [10, 20, 30, 40],
+        [5, 10, 20, 30],
+    ]
 
     assert client.json().arrindex(
         "store", "$.store.book[?(@.price<10)].size", "20"
@@ -1315,7 +1320,7 @@ def test_arrindex_dollar(client):
         "3",
         [],
     ]
-    assert_resp_response(client, client.json().get("test_num", "$..arr"), res, [res])
+    assert client.json().get("test_num", "$..arr") == res
 
     assert client.json().arrindex("test_num", "$..arr", 3) == [3, 2, -1, None, -1]
 
@@ -1348,7 +1353,7 @@ def test_arrindex_dollar(client):
         "3",
         [],
     ]
-    assert_resp_response(client, client.json().get("test_string", "$..arr"), res, [res])
+    assert client.json().get("test_string", "$..arr") == res
 
     assert client.json().arrindex("test_string", "$..arr", "baz") == [
         3,
@@ -1441,7 +1446,7 @@ def test_arrindex_dollar(client):
         None,
         [],
     ]
-    assert_resp_response(client, client.json().get("test_None", "$..arr"), res, [res])
+    assert client.json().get("test_None", "$..arr") == res
 
     # Test with none-scalar value
     assert client.json().arrindex(
@@ -1463,6 +1468,7 @@ def test_arrindex_dollar(client):
     assert client.json().arrindex("test_None", "..nested2_not_found.arr", "None") == 0
 
 
+@pytest.mark.redismod
 def test_decoders_and_unstring():
     assert unstring("4") == 4
     assert unstring("45.55") == 45.55
@@ -1473,6 +1479,7 @@ def test_decoders_and_unstring():
     assert decode_list(["hello", b"world"]) == ["hello", "world"]
 
 
+@pytest.mark.redismod
 def test_custom_decoder(client):
     import json
 
@@ -1480,7 +1487,7 @@ def test_custom_decoder(client):
 
     cj = client.json(encoder=ujson, decoder=ujson)
     assert cj.set("foo", Path.root_path(), "bar")
-    assert_resp_response(client, cj.get("foo"), "bar", [["bar"]])
+    assert cj.get("foo") == "bar"
     assert cj.get("baz") is None
     assert 1 == cj.delete("foo")
     assert client.exists("foo") == 0
@@ -1488,6 +1495,7 @@ def test_custom_decoder(client):
     assert not isinstance(cj.__decoder__, json.JSONDecoder)
 
 
+@pytest.mark.redismod
 def test_set_file(client):
     import json
     import tempfile
@@ -1501,11 +1509,12 @@ def test_set_file(client):
     nojsonfile.write(b"Hello World")
 
     assert client.json().set_file("test", Path.root_path(), jsonfile.name)
-    assert_resp_response(client, client.json().get("test"), obj, [[obj]])
+    assert client.json().get("test") == obj
     with pytest.raises(json.JSONDecodeError):
         client.json().set_file("test2", Path.root_path(), nojsonfile.name)
 
 
+@pytest.mark.redismod
 def test_set_path(client):
     import json
     import tempfile
@@ -1523,6 +1532,4 @@ def test_set_path(client):
     result = {jsonfile: True, nojsonfile: False}
     assert client.json().set_path(Path.root_path(), root) == result
     res = {"hello": "world"}
-    assert_resp_response(
-        client, client.json().get(jsonfile.rsplit(".")[0]), res, [[res]]
-    )
+    assert client.json().get(jsonfile.rsplit(".")[0]) == res
