@@ -5,7 +5,20 @@ from time import sleep
 import pytest
 import redis
 
-from .conftest import assert_resp_response, is_resp2_connection, skip_ifmodversion_lt
+from .conftest import (
+    _get_client,
+    assert_resp_response,
+    is_resp2_connection,
+    skip_ifmodversion_lt,
+)
+
+
+@pytest.fixture()
+def decoded_r(request, stack_url):
+    with _get_client(
+        redis.Redis, request, decode_responses=True, from_url=stack_url
+    ) as client:
+        yield client
 
 
 @pytest.fixture
@@ -14,6 +27,7 @@ def client(decoded_r):
     return decoded_r
 
 
+@pytest.mark.redismod
 def test_create(client):
     assert client.ts().create(1)
     assert client.ts().create(2, retention_msecs=5)
@@ -31,6 +45,7 @@ def test_create(client):
     assert_resp_response(client, 128, info.get("chunk_size"), info.get("chunkSize"))
 
 
+@pytest.mark.redismod
 @skip_ifmodversion_lt("1.4.0", "timeseries")
 def test_create_duplicate_policy(client):
     # Test for duplicate policy
@@ -46,6 +61,7 @@ def test_create_duplicate_policy(client):
         )
 
 
+@pytest.mark.redismod
 def test_alter(client):
     assert client.ts().create(1)
     info = client.ts().info(1)
@@ -66,8 +82,9 @@ def test_alter(client):
     )
 
 
+@pytest.mark.redismod
 @skip_ifmodversion_lt("1.4.0", "timeseries")
-def test_alter_diplicate_policy(client):
+def test_alter_duplicate_policy(client):
     assert client.ts().create(1)
     info = client.ts().info(1)
     assert_resp_response(
@@ -80,6 +97,7 @@ def test_alter_diplicate_policy(client):
     )
 
 
+@pytest.mark.redismod
 def test_add(client):
     assert 1 == client.ts().add(1, 1, 1)
     assert 2 == client.ts().add(2, 2, 3, retention_msecs=10)
@@ -102,47 +120,53 @@ def test_add(client):
     assert_resp_response(client, 128, info.get("chunk_size"), info.get("chunkSize"))
 
 
+@pytest.mark.redismod
 @skip_ifmodversion_lt("1.4.0", "timeseries")
-def test_add_duplicate_policy(client):
+def test_add_on_duplicate(client):
     # Test for duplicate policy BLOCK
     assert 1 == client.ts().add("time-serie-add-ooo-block", 1, 5.0)
     with pytest.raises(Exception):
-        client.ts().add("time-serie-add-ooo-block", 1, 5.0, duplicate_policy="block")
+        client.ts().add("time-serie-add-ooo-block", 1, 5.0, on_duplicate="block")
 
     # Test for duplicate policy LAST
     assert 1 == client.ts().add("time-serie-add-ooo-last", 1, 5.0)
-    assert 1 == client.ts().add(
-        "time-serie-add-ooo-last", 1, 10.0, duplicate_policy="last"
-    )
+    assert 1 == client.ts().add("time-serie-add-ooo-last", 1, 10.0, on_duplicate="last")
     assert 10.0 == client.ts().get("time-serie-add-ooo-last")[1]
 
     # Test for duplicate policy FIRST
     assert 1 == client.ts().add("time-serie-add-ooo-first", 1, 5.0)
     assert 1 == client.ts().add(
-        "time-serie-add-ooo-first", 1, 10.0, duplicate_policy="first"
+        "time-serie-add-ooo-first", 1, 10.0, on_duplicate="first"
     )
     assert 5.0 == client.ts().get("time-serie-add-ooo-first")[1]
 
     # Test for duplicate policy MAX
     assert 1 == client.ts().add("time-serie-add-ooo-max", 1, 5.0)
-    assert 1 == client.ts().add(
-        "time-serie-add-ooo-max", 1, 10.0, duplicate_policy="max"
-    )
+    assert 1 == client.ts().add("time-serie-add-ooo-max", 1, 10.0, on_duplicate="max")
     assert 10.0 == client.ts().get("time-serie-add-ooo-max")[1]
 
     # Test for duplicate policy MIN
     assert 1 == client.ts().add("time-serie-add-ooo-min", 1, 5.0)
-    assert 1 == client.ts().add(
-        "time-serie-add-ooo-min", 1, 10.0, duplicate_policy="min"
-    )
+    assert 1 == client.ts().add("time-serie-add-ooo-min", 1, 10.0, on_duplicate="min")
     assert 5.0 == client.ts().get("time-serie-add-ooo-min")[1]
 
 
+@pytest.mark.redismod
 def test_madd(client):
     client.ts().create("a")
     assert [1, 2, 3] == client.ts().madd([("a", 1, 5), ("a", 2, 10), ("a", 3, 15)])
 
 
+@pytest.mark.redismod
+def test_madd_missing_timeseries(client):
+    response = client.ts().madd([("a", 1, 5), ("a", 2, 10)])
+    assert isinstance(response, list)
+    assert len(response) == 2
+    assert isinstance(response[0], redis.ResponseError)
+    assert isinstance(response[1], redis.ResponseError)
+
+
+@pytest.mark.redismod
 def test_incrby_decrby(client):
     for _ in range(100):
         assert client.ts().incrby(1, 1)
@@ -171,7 +195,7 @@ def test_incrby_decrby(client):
     assert_resp_response(client, 128, info.get("chunk_size"), info.get("chunkSize"))
 
 
-@pytest.mark.onlynoncluster
+@pytest.mark.redismod
 def test_create_and_delete_rule(client):
     # test rule creation
     time = 100
@@ -195,12 +219,13 @@ def test_create_and_delete_rule(client):
     assert not info["rules"]
 
 
-@skip_ifmodversion_lt("99.99.99", "timeseries")
+@pytest.mark.redismod
+@skip_ifmodversion_lt("1.10.0", "timeseries")
 def test_del_range(client):
     try:
         client.ts().delete("test", 0, 100)
-    except Exception as e:
-        assert e.__str__() != ""
+    except redis.ResponseError as e:
+        assert "key does not exist" in str(e)
 
     for i in range(100):
         client.ts().add(1, i, i % 7)
@@ -209,6 +234,7 @@ def test_del_range(client):
     assert_resp_response(client, client.ts().range(1, 22, 22), [(22, 1.0)], [[22, 1.0]])
 
 
+@pytest.mark.redismod
 def test_range(client):
     for i in range(100):
         client.ts().add(1, i, i % 7)
@@ -223,7 +249,8 @@ def test_range(client):
     assert 10 == len(client.ts().range(1, 0, 500, count=10))
 
 
-@skip_ifmodversion_lt("99.99.99", "timeseries")
+@pytest.mark.redismod
+@skip_ifmodversion_lt("1.10.0", "timeseries")
 def test_range_advanced(client):
     for i in range(100):
         client.ts().add(1, i, i % 7)
@@ -252,6 +279,7 @@ def test_range_advanced(client):
 
 
 @pytest.mark.onlynoncluster
+@pytest.mark.redismod
 @skip_ifmodversion_lt("1.8.0", "timeseries")
 def test_range_latest(client: redis.Redis):
     timeseries = client.ts()
@@ -276,6 +304,7 @@ def test_range_latest(client: redis.Redis):
     )
 
 
+@pytest.mark.redismod
 @skip_ifmodversion_lt("1.8.0", "timeseries")
 def test_range_bucket_timestamp(client: redis.Redis):
     timeseries = client.ts()
@@ -309,6 +338,7 @@ def test_range_bucket_timestamp(client: redis.Redis):
     )
 
 
+@pytest.mark.redismod
 @skip_ifmodversion_lt("1.8.0", "timeseries")
 def test_range_empty(client: redis.Redis):
     timeseries = client.ts()
@@ -353,7 +383,8 @@ def test_range_empty(client: redis.Redis):
     assert_resp_response(client, res, resp2_expected, resp3_expected)
 
 
-@skip_ifmodversion_lt("99.99.99", "timeseries")
+@pytest.mark.redismod
+@skip_ifmodversion_lt("1.10.0", "timeseries")
 def test_rev_range(client):
     for i in range(100):
         client.ts().add(1, i, i % 7)
@@ -401,6 +432,7 @@ def test_rev_range(client):
 
 
 @pytest.mark.onlynoncluster
+@pytest.mark.redismod
 @skip_ifmodversion_lt("1.8.0", "timeseries")
 def test_revrange_latest(client: redis.Redis):
     timeseries = client.ts()
@@ -419,6 +451,7 @@ def test_revrange_latest(client: redis.Redis):
     assert_resp_response(client, res, [(0, 4.0)], [[0, 4.0]])
 
 
+@pytest.mark.redismod
 @skip_ifmodversion_lt("1.8.0", "timeseries")
 def test_revrange_bucket_timestamp(client: redis.Redis):
     timeseries = client.ts()
@@ -452,6 +485,7 @@ def test_revrange_bucket_timestamp(client: redis.Redis):
     )
 
 
+@pytest.mark.redismod
 @skip_ifmodversion_lt("1.8.0", "timeseries")
 def test_revrange_empty(client: redis.Redis):
     timeseries = client.ts()
@@ -497,6 +531,7 @@ def test_revrange_empty(client: redis.Redis):
 
 
 @pytest.mark.onlynoncluster
+@pytest.mark.redismod
 def test_mrange(client):
     client.ts().create(1, labels={"Test": "This", "team": "ny"})
     client.ts().create(2, labels={"Test": "This", "Taste": "That", "team": "sf"})
@@ -545,7 +580,8 @@ def test_mrange(client):
 
 
 @pytest.mark.onlynoncluster
-@skip_ifmodversion_lt("99.99.99", "timeseries")
+@pytest.mark.redismod
+@skip_ifmodversion_lt("1.10.0", "timeseries")
 def test_multi_range_advanced(client):
     client.ts().create(1, labels={"Test": "This", "team": "ny"})
     client.ts().create(2, labels={"Test": "This", "Taste": "That", "team": "sf"})
@@ -658,6 +694,7 @@ def test_multi_range_advanced(client):
 
 
 @pytest.mark.onlynoncluster
+@pytest.mark.redismod
 @skip_ifmodversion_lt("1.8.0", "timeseries")
 def test_mrange_latest(client: redis.Redis):
     timeseries = client.ts()
@@ -687,7 +724,8 @@ def test_mrange_latest(client: redis.Redis):
 
 
 @pytest.mark.onlynoncluster
-@skip_ifmodversion_lt("99.99.99", "timeseries")
+@pytest.mark.redismod
+@skip_ifmodversion_lt("1.10.0", "timeseries")
 def test_multi_reverse_range(client):
     client.ts().create(1, labels={"Test": "This", "team": "ny"})
     client.ts().create(2, labels={"Test": "This", "Taste": "That", "team": "sf"})
@@ -805,6 +843,7 @@ def test_multi_reverse_range(client):
 
 
 @pytest.mark.onlynoncluster
+@pytest.mark.redismod
 @skip_ifmodversion_lt("1.8.0", "timeseries")
 def test_mrevrange_latest(client: redis.Redis):
     timeseries = client.ts()
@@ -833,6 +872,7 @@ def test_mrevrange_latest(client: redis.Redis):
     )
 
 
+@pytest.mark.redismod
 def test_get(client):
     name = "test"
     client.ts().create(name)
@@ -844,6 +884,7 @@ def test_get(client):
 
 
 @pytest.mark.onlynoncluster
+@pytest.mark.redismod
 @skip_ifmodversion_lt("1.8.0", "timeseries")
 def test_get_latest(client: redis.Redis):
     timeseries = client.ts()
@@ -861,6 +902,7 @@ def test_get_latest(client: redis.Redis):
 
 
 @pytest.mark.onlynoncluster
+@pytest.mark.redismod
 def test_mget(client):
     client.ts().create(1, labels={"Test": "This"})
     client.ts().create(2, labels={"Test": "This", "Taste": "That"})
@@ -896,6 +938,7 @@ def test_mget(client):
 
 
 @pytest.mark.onlynoncluster
+@pytest.mark.redismod
 @skip_ifmodversion_lt("1.8.0", "timeseries")
 def test_mget_latest(client: redis.Redis):
     timeseries = client.ts()
@@ -912,6 +955,7 @@ def test_mget_latest(client: redis.Redis):
     assert_resp_response(client, res, [{"t2": [{}, 10, 8.0]}], {"t2": [{}, [10, 8.0]]})
 
 
+@pytest.mark.redismod
 def test_info(client):
     client.ts().create(1, retention_msecs=5, labels={"currentLabel": "currentData"})
     info = client.ts().info(1)
@@ -921,8 +965,9 @@ def test_info(client):
     assert info["labels"]["currentLabel"] == "currentData"
 
 
+@pytest.mark.redismod
 @skip_ifmodversion_lt("1.4.0", "timeseries")
-def testInfoDuplicatePolicy(client):
+def test_info_duplicate_policy(client):
     client.ts().create(1, retention_msecs=5, labels={"currentLabel": "currentData"})
     info = client.ts().info(1)
     assert_resp_response(
@@ -936,6 +981,7 @@ def testInfoDuplicatePolicy(client):
     )
 
 
+@pytest.mark.redismod
 @pytest.mark.onlynoncluster
 def test_query_index(client):
     client.ts().create(1, labels={"Test": "This"})
@@ -945,6 +991,7 @@ def test_query_index(client):
     assert_resp_response(client, client.ts().queryindex(["Taste=That"]), [2], {"2"})
 
 
+@pytest.mark.redismod
 def test_pipeline(client):
     pipeline = client.ts().pipeline()
     pipeline.create("with_pipeline")
@@ -962,12 +1009,179 @@ def test_pipeline(client):
     assert client.ts().get("with_pipeline")[1] == 99 * 1.1
 
 
+@pytest.mark.redismod
 def test_uncompressed(client):
     client.ts().create("compressed")
     client.ts().create("uncompressed", uncompressed=True)
+    for i in range(1000):
+        client.ts().add("compressed", i, i)
+        client.ts().add("uncompressed", i, i)
     compressed_info = client.ts().info("compressed")
     uncompressed_info = client.ts().info("uncompressed")
     if is_resp2_connection(client):
-        assert compressed_info.memory_usage != uncompressed_info.memory_usage
+        assert compressed_info.memory_usage < uncompressed_info.memory_usage
     else:
-        assert compressed_info["memoryUsage"] != uncompressed_info["memoryUsage"]
+        assert compressed_info["memoryUsage"] < uncompressed_info["memoryUsage"]
+
+
+@pytest.mark.redismod
+@skip_ifmodversion_lt("1.12.0", "timeseries")
+def test_create_with_insertion_filters(client):
+    client.ts().create(
+        "time-series-1",
+        duplicate_policy="last",
+        ignore_max_time_diff=5,
+        ignore_max_val_diff=10.0,
+    )
+    assert 1000 == client.ts().add("time-series-1", 1000, 1.0)
+    assert 1010 == client.ts().add("time-series-1", 1010, 11.0)
+    assert 1010 == client.ts().add("time-series-1", 1013, 10.0)
+    assert 1020 == client.ts().add("time-series-1", 1020, 11.5)
+    assert 1021 == client.ts().add("time-series-1", 1021, 22.0)
+
+    data_points = client.ts().range("time-series-1", "-", "+")
+    assert_resp_response(
+        client,
+        data_points,
+        [(1000, 1.0), (1010, 11.0), (1020, 11.5), (1021, 22.0)],
+        [[1000, 1.0], [1010, 11.0], [1020, 11.5], [1021, 22.0]],
+    )
+
+
+@pytest.mark.redismod
+@skip_ifmodversion_lt("1.12.0", "timeseries")
+def test_create_with_insertion_filters_other_duplicate_policy(client):
+    client.ts().create(
+        "time-series-1",
+        ignore_max_time_diff=5,
+        ignore_max_val_diff=10.0,
+    )
+    assert 1000 == client.ts().add("time-series-1", 1000, 1.0)
+    assert 1010 == client.ts().add("time-series-1", 1010, 11.0)
+    # Still accepted because the duplicate_policy is not `last`.
+    assert 1013 == client.ts().add("time-series-1", 1013, 10.0)
+
+    data_points = client.ts().range("time-series-1", "-", "+")
+    assert_resp_response(
+        client,
+        data_points,
+        [(1000, 1.0), (1010, 11.0), (1013, 10)],
+        [[1000, 1.0], [1010, 11.0], [1013, 10]],
+    )
+
+
+@pytest.mark.redismod
+@skip_ifmodversion_lt("1.12.0", "timeseries")
+def test_alter_with_insertion_filters(client):
+    assert 1000 == client.ts().add("time-series-1", 1000, 1.0)
+    assert 1010 == client.ts().add("time-series-1", 1010, 11.0)
+    assert 1013 == client.ts().add("time-series-1", 1013, 10.0)
+
+    client.ts().alter(
+        "time-series-1",
+        duplicate_policy="last",
+        ignore_max_time_diff=5,
+        ignore_max_val_diff=10.0,
+    )
+
+    assert 1013 == client.ts().add("time-series-1", 1015, 11.5)
+
+    data_points = client.ts().range("time-series-1", "-", "+")
+    assert_resp_response(
+        client,
+        data_points,
+        [(1000, 1.0), (1010, 11.0), (1013, 10.0)],
+        [[1000, 1.0], [1010, 11.0], [1013, 10.0]],
+    )
+
+
+@pytest.mark.redismod
+@skip_ifmodversion_lt("1.12.0", "timeseries")
+def test_add_with_insertion_filters(client):
+    assert 1000 == client.ts().add(
+        "time-series-1",
+        1000,
+        1.0,
+        duplicate_policy="last",
+        ignore_max_time_diff=5,
+        ignore_max_val_diff=10.0,
+    )
+
+    assert 1000 == client.ts().add("time-series-1", 1004, 3.0)
+
+    data_points = client.ts().range("time-series-1", "-", "+")
+    assert_resp_response(client, data_points, [(1000, 1.0)], [[1000, 1.0]])
+
+
+@pytest.mark.redismod
+@skip_ifmodversion_lt("1.12.0", "timeseries")
+def test_incrby_with_insertion_filters(client):
+    assert 1000 == client.ts().incrby(
+        "time-series-1",
+        1.0,
+        timestamp=1000,
+        duplicate_policy="last",
+        ignore_max_time_diff=5,
+        ignore_max_val_diff=10.0,
+    )
+
+    assert 1000 == client.ts().incrby("time-series-1", 3.0, timestamp=1000)
+
+    data_points = client.ts().range("time-series-1", "-", "+")
+    assert_resp_response(client, data_points, [(1000, 1.0)], [[1000, 1.0]])
+
+    assert 1000 == client.ts().incrby("time-series-1", 10.1, timestamp=1000)
+
+    data_points = client.ts().range("time-series-1", "-", "+")
+    assert_resp_response(client, data_points, [(1000, 11.1)], [[1000, 11.1]])
+
+
+@pytest.mark.redismod
+@skip_ifmodversion_lt("1.12.0", "timeseries")
+def test_decrby_with_insertion_filters(client):
+    assert 1000 == client.ts().decrby(
+        "time-series-1",
+        1.0,
+        timestamp=1000,
+        duplicate_policy="last",
+        ignore_max_time_diff=5,
+        ignore_max_val_diff=10.0,
+    )
+
+    assert 1000 == client.ts().decrby("time-series-1", 3.0, timestamp=1000)
+
+    data_points = client.ts().range("time-series-1", "-", "+")
+    assert_resp_response(client, data_points, [(1000, -1.0)], [[1000, -1.0]])
+
+    assert 1000 == client.ts().decrby("time-series-1", 10.1, timestamp=1000)
+
+    data_points = client.ts().range("time-series-1", "-", "+")
+    assert_resp_response(client, data_points, [(1000, -11.1)], [[1000, -11.1]])
+
+
+@pytest.mark.redismod
+@skip_ifmodversion_lt("1.12.0", "timeseries")
+def test_madd_with_insertion_filters(client):
+    client.ts().create(
+        "time-series-1",
+        duplicate_policy="last",
+        ignore_max_time_diff=5,
+        ignore_max_val_diff=10.0,
+    )
+    assert 1010 == client.ts().add("time-series-1", 1010, 1.0)
+    assert [1010, 1010, 1020, 1021] == client.ts().madd(
+        [
+            ("time-series-1", 1011, 11.0),
+            ("time-series-1", 1013, 10.0),
+            ("time-series-1", 1020, 2.0),
+            ("time-series-1", 1021, 22.0),
+        ]
+    )
+
+    data_points = client.ts().range("time-series-1", "-", "+")
+    assert_resp_response(
+        client,
+        data_points,
+        [(1010, 1.0), (1020, 2.0), (1021, 22.0)],
+        [[1010, 1.0], [1020, 2.0], [1021, 22.0]],
+    )
